/*
*  
*  $Id: comandoavisarficheros.h 3839 2011-05-11 08:47:59Z tovar $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma once
//#define _GINKGO_TRACE
#include <api/api.h>
#include <api/globals.h>
#include <api/icomando.h>
#include <api/ientorno.h>
#include <api/icontroladoreventos.h>
#include <api/imodelointegracion.h>

namespace GADAPI {
	class EXTAPI ComandoAvisarFicherosParams : public GNC::GCS::IComandoParams
	{
	public:
		typedef std::list<std::string> TipoListaFicheros;

		ComandoAvisarFicherosParams(const TipoListaFicheros& listaFicheros, bool openAfter = false);

		TipoListaFicheros m_listaFicheros;
		bool m_openAfter;
	};

	class EXTAPI ComandoAvisarFicheros : public GNC::GCS::IComando {
	public:
		ComandoAvisarFicheros(ComandoAvisarFicherosParams* pParams);

	 protected:
		virtual void Execute();
		virtual void Update();;

		void LiberarRecursos();

	protected:
		ComandoAvisarFicherosParams* m_pAvisarParams;
	};
}
